********************************************************************************
* Analyzes the data of the "Negotiating Climate Cooperation" experiments by Schmidt and Ockenfels
*
* Generating data set
* 
* Structure
* 1) Single dta-file from txt-files
* 2) Definition of new variables
*
********************************************************************************

clear
capture log close
set matsize 800
set more off

cd "C:\Dateien\New_Papers\Climate Change\PNAS\Data and Code"


************************************************************************
***************                                         ****************
***************    SINGLE DTA-FILE FROM TXT-FILES       ****************
***************                                         ****************
************************************************************************


* Source files are the excel files generated by hand from the oTree files saved as txt files


insheet using CCC_AE1_180115.txt, clear
compress
save CLIMATE_CCC_1.dta, replace

insheet using CCC_AE2_180116.txt, clear
compress
save CLIMATE_CCC_2.dta, replace

insheet using CCC_AE3_180116.txt, clear
compress
save CLIMATE_CCC_3.dta, replace

insheet using IC_AE1_180115.txt, clear
compress
save CLIMATE_IC_1.dta, replace

insheet using IC_AE2_180117.txt, clear
compress
save CLIMATE_IC_2.dta, replace

insheet using IC_AE3_180117.txt, clear
compress
save CLIMATE_IC_3.dta, replace

insheet using UCC_AE1_180115.txt, clear
compress
save CLIMATE_UCC_1.dta, replace

insheet using UCC_AE2_180116.txt, clear
compress
save CLIMATE_UCC_2.dta, replace

insheet using UCC_AE3_180118.txt, clear
compress
save CLIMATE_UCC_3.dta, replace


insheet using CCC_SE1_180118.txt, clear
compress
save CLIMATE_CCC_4.dta, replace

insheet using CCC_ANE1_180118.txt, clear
compress
save CLIMATE_CCC_5.dta, replace

insheet using UCC_ANE1_180122.txt, clear
compress
save CLIMATE_UCC_4.dta, replace

insheet using UCC_SE1_180122.txt, clear
compress
save CLIMATE_UCC_5.dta, replace

insheet using CCC_SE2_180123.txt, clear
compress
save CLIMATE_CCC_6.dta, replace

insheet using IC_ANE1_180125.txt, clear
compress
save CLIMATE_IC_4.dta, replace

insheet using UCC_ANE2_180125.txt, clear
compress
save CLIMATE_UCC_6.dta, replace

insheet using IC_SE1_180219.txt, clear
compress
save CLIMATE_IC_5.dta, replace

insheet using UCC_ANE3_180219.txt, clear
compress
save CLIMATE_UCC_7.dta, replace

insheet using UCC_SE2_180221.txt, clear
compress
save CLIMATE_UCC_8.dta, replace

insheet using IC_ANE2_180228.txt, clear
compress
save CLIMATE_IC_6.dta, replace

insheet using CCC_ANE2_180228.txt, clear
compress
save CLIMATE_CCC_7.dta, replace

insheet using IC_SE2_180228.txt, clear
compress
save CLIMATE_IC_7.dta, replace


*merge data sets
use CLIMATE_CCC_1.dta
foreach sessiontitle in IC_1 UCC_1 ///
CCC_2 IC_2 UCC_2 CCC_3 CCC_4 CCC_5 CCC_6 IC_3 UCC_3 ///
UCC_4 UCC_5 UCC_6 UCC_7 UCC_8 ///
IC_4 IC_5 IC_6 CCC_7 IC_7{
append using CLIMATE_`sessiontitle'.dta
}


************************************************************************
***************                                         ****************
***************     DEFINITION OF NEW VARIABLES         ****************
***************                                         ****************
************************************************************************


***** Labelling sessions 


gen     ses_number=0
replace ses_number=1 if (date==180115 & treat_a=="minimum")
replace ses_number=2 if (date==180115 & treat_a=="kyoto")
replace ses_number=3 if (date==180115 & treat_a=="paris")
replace ses_number=4 if (date==180116 & treat_a=="kyoto" & session_code=="79pu8tir")
replace ses_number=5 if (date==180116 & treat_a=="kyoto" & session_code=="jme6unu4")
replace ses_number=6 if (date==180116 & treat_a=="minimum")
replace ses_number=7 if (date==180117 & treat_a=="paris" & session_code=="5e6bl8gq")
replace ses_number=8 if (date==180117 & treat_a=="paris" & session_code=="c5cttw45")
replace ses_number=9 if (date==180118 & treat_a=="minimum")
replace ses_number=10 if (date==180118 & treat_a=="kyoto" & treat_b=="symmetric")
replace ses_number=11 if (date==180118 & treat_a=="kyoto" & treat_c=="notenforced")
replace ses_number=12 if (date==180122 & treat_a=="minimum" & treat_c=="notenforced")
replace ses_number=13 if (date==180122 & treat_a=="minimum" & treat_b=="symmetric")
replace ses_number=14 if (date==180123 & treat_a=="kyoto" & treat_b=="symmetric")
replace ses_number=15 if (date==180125 & treat_a=="paris" & treat_c=="notenforced")
replace ses_number=16 if (date==180125 & treat_a=="minimum" & treat_c=="notenforced")
replace ses_number=17 if (date==180219 & treat_a=="paris" & treat_b=="symmetric")
replace ses_number=18 if (date==180219 & treat_a=="minimum" & treat_c=="notenforced")
replace ses_number=19 if (date==180221 & treat_a=="minimum" & treat_b=="symmetric")
replace ses_number=20 if (date==180228 & treat_a=="paris" & treat_c=="notenforced")
replace ses_number=21 if (date==180228 & treat_a=="kyoto" & treat_c=="notenforced")
replace ses_number=22 if (date==180228 & treat_a=="paris" & treat_b=="symmetric")



***** labelling treatments

gen     treatment="0"
replace treatment="UCC"    if ses_number == 1 | ses_number == 6 | ses_number == 9  | ses_number == 12 | ses_number == 13 | ses_number == 16 | ses_number == 18 | ses_number == 19
replace treatment="CCC"    if ses_number == 2 | ses_number == 4 | ses_number == 5 | ses_number == 10 | ses_number == 11 | ses_number == 14 | ses_number == 21
replace treatment="IC"    if ses_number == 3 | ses_number == 7 | ses_number == 8 | ses_number == 15 | ses_number == 17 | ses_number == 20 | ses_number == 22  
 
tab treatment

***** creating dummy variables for treatments


gen CCC=0
replace CCC=1 if treat_a=="kyoto"
*label variable CCC "dummy variable, 1 if CCC"
label variable CCC "CCC"

gen IC=0
replace IC=1 if treat_a=="paris"
*label variable IC "dummy variable, 1 if IC"
label variable IC "IC"

gen UCC=0
replace UCC=1 if treat_a=="minimum"
*label variable min "dummy variable, 1 if UCC"
label variable UCC "UCC"

gen main=0
replace main=1 if treat_c=="enforced" & treat_b=="asymmetric"
*label variable main "dummy variable, 1 if main treatment"
label variable main "main treatment"

gen notenforced=0
replace notenforced=1 if treat_c=="notenforced"
*label variable notenforced "dummy variable, 1 if not enforced"
label variable notenforced "not enforced"

gen symmetric=0
replace symmetric=1 if treat_b=="symmetric"
*label variable symmetric "dummy variable, 1 if symmetric"
label variable symmetric "symmetric"

gen UCC_M=0
replace UCC_M=1 if ses_number == 1 | ses_number == 6 | ses_number == 9  
*label variable UCC_M "dummy variable, 1 if Main UCC Treatment"
label variable UCC_M "UCC_M"

gen CCC_M=0
replace CCC_M=1 if ses_number == 2 | ses_number == 4 | ses_number == 5 
*label variable CCC_M "dummy variable, 1 if Main CCC Treatment"
label variable CCC_M "CCC_M"

gen IC_M=0
replace IC_M=1 if ses_number == 3 | ses_number == 7 | ses_number == 8
*label variable IC_M "dummy variable, 1 if Main IC Treatment"
label variable IC_M "IC_M"

gen UCC_S=0
replace UCC_S=1 if ses_number == 13 | ses_number == 19
label variable UCC_S "dummy variable, 1 if Symmetric UCC Treatment"

gen CCC_S=0
replace CCC_S=1 if ses_number == 10 | ses_number == 14  
label variable CCC_S "dummy variable, 1 if Symmetric CCC Treatment"

gen IC_S=0
replace IC_S=1 if ses_number == 17 | ses_number == 22
label variable IC_S "dummy variable, 1 if Symmetric IC Treatment"

gen UCC_NE=0
replace UCC_NE=1 if ses_number == 12 | ses_number == 16 | ses_number == 18  
label variable UCC_NE "dummy variable, 1 if UCC NotEnforced Treatment"

gen CCC_NE=0
replace CCC_NE=1 if ses_number == 11 | ses_number == 21
label variable CCC_NE "dummy variable, 1 if CCC NotEnforced Treatment"

gen IC_NE=0
replace IC_NE=1 if ses_number == 15 | ses_number == 20
label variable IC_NE "dummy variable, 1 if IC NotEnforced Treatment"


gen sub_treatment="0"
replace sub_treatment="1_IC_M" if IC_M == 1
replace sub_treatment="2_CCC_M" if CCC_M == 1
replace sub_treatment="3_UCC_M" if UCC_M == 1
replace sub_treatment="4_IC_NE" if IC_NE == 1
replace sub_treatment="5_CCC_NE" if CCC_NE == 1
replace sub_treatment="6_UCC_NE" if UCC_NE ==1
replace sub_treatment="7_IC_S" if IC_S == 1
replace sub_treatment="8_CCC_S" if CCC_S == 1
replace sub_treatment="9_UCC_S" if UCC_S == 1
tab sub_treatment



***** Labelling matching groups

generate match=0
replace match=1 if ses_number==1 & matching==1
replace match=2 if ses_number==1 & matching==2
replace match=3 if ses_number==2 & matching==1
replace match=4 if ses_number==2 & matching==2
replace match=5 if ses_number==3 & matching==1
replace match=6 if ses_number==3 & matching==2
replace match=7 if ses_number==4 & matching==1
replace match=8 if ses_number==4 & matching==2
replace match=9 if ses_number==5 & matching==1
replace match=10 if ses_number==5 & matching==2
replace match=11 if ses_number==6 & matching==1
replace match=12 if ses_number==6 & matching==2
replace match=13 if ses_number==7 & matching==1
replace match=14 if ses_number==7 & matching==2
replace match=15 if ses_number==8 & matching==1
replace match=16 if ses_number==8 & matching==2
replace match=17 if ses_number==9 & matching==1
replace match=18 if ses_number==9 & matching==2
replace match=19 if ses_number==10 & matching==1
replace match=20 if ses_number==10 & matching==2
replace match=21 if ses_number==11 & matching==1
replace match=22 if ses_number==11 & matching==2
replace match=23 if ses_number==12 & matching==1
replace match=24 if ses_number==12 & matching==2
replace match=25 if ses_number==13 & matching==1
replace match=26 if ses_number==13 & matching==2
replace match=27 if ses_number==14 & matching==1
replace match=28 if ses_number==14 & matching==2
replace match=29 if ses_number==15 & matching==1
replace match=30 if ses_number==15 & matching==2
replace match=31 if ses_number==16 & matching==1
replace match=32 if ses_number==16 & matching==2
replace match=33 if ses_number==17 & matching==1
replace match=34 if ses_number==17 & matching==2
replace match=35 if ses_number==18 & matching==1
replace match=36 if ses_number==18 & matching==2
replace match=37 if ses_number==19 & matching==1
replace match=38 if ses_number==19 & matching==2
replace match=39 if ses_number==20 & matching==1
replace match=40 if ses_number==20 & matching==2
replace match=41 if ses_number==21 & matching==1
replace match=42 if ses_number==21 & matching==2
replace match=43 if ses_number==22 & matching==1
replace match=44 if ses_number==22 & matching==2

tab match 




***** labelling subjects 
gen subjectident = 100*ses_number + subject_id
gen groupid   = 100*ses_number + group

sum subjectident
sum groupid


***** labelling rounds

gen R1=0
replace R1=1 if round == 1  
label variable R1 "dummy variable, 1 if round=1"

gen R2=0
replace R2=1 if round == 2  
label variable R2 "dummy variable, 1 if round=2"

gen R3=0
replace R3=1 if round == 3  
label variable R3 "dummy variable, 1 if round=3"

gen R4=0
replace R4=1 if round == 4  
label variable R4 "dummy variable, 1 if round=4"

gen R5=0
replace R5=1 if round == 5  
label variable R5 "dummy variable, 1 if round=5"


***** labelling types

gen A=0
replace A=1 if type == 1  
*label variable A "dummy variable, 1 if type=1"
label variable A "type A"


gen B=0
replace B=1 if type == 2  
*label variable B "dummy variable, 1 if type=2"
label variable B "type B"

gen C=0
replace C=1 if type == 3  
*label variable C "dummy variable, 1 if type=3"
label variable C "type C"

gen D=0
replace D=1 if type == 4  
*label variable D "dummy variable, 1 if type=4"
label variable D "type D"


generate AA=0
replace AA=1 if A==1 & symmetric==0
*label variable AA "dummy variable, 1 if type=1 and asymmetric"
label variable AA "type A asymmetric"

generate BA=0
replace BA=1 if B==1 & symmetric==0
*label variable BA "dummy variable, 1 if type=2 and asymmetric"
label variable BA "type B asymmetric"

generate CA=0
replace CA=1 if C==1 & symmetric==0
*label variable CA "dummy variable, 1 if type=3 and asymmetric"
label variable CA "type C asymmetric"

generate DA=0
replace DA=1 if D==1 & symmetric==0
*label variable DA "dummy variable, 1 if type=4 and asymmetric"
label variable DA "type D asymmetric"




***** labelling demographic variables

gen female=0
replace female=1 if sex == "Weiblich"
label variable female "female"

generate ageclass=0
replace ageclass=10 if age < 20
replace ageclass=20 if age >=20 & age < 30
replace ageclass=30 if age >= 30 & age < 40
replace ageclass=40 if age > 40 

tab ageclass if round==1

generate mother_tongue="german"
replace mother_tongue="other" if language == "Andere Sprache" 

generate field="null"
replace field="1_econ" if study == "VWL" 
replace field="2_bus" if study == "BWL" 
replace field="3_law" if study == "Rechtswissenschaft" 
replace field="4_psych" if study == "Psychologie" 
replace field="5_social" if study == "Andere Sozial- oder Wirtschaftswissenschaft" 
replace field="6_humanities" if study == "Geisteswissenschaft" 
replace field="7_natural" if study == "Naturwissenschaft/Technik" 
replace field="8_other" if study == "Sonstiges" 

generate econ=0
replace econ=1 if (field=="1_econ" | field=="2_bus")
*label variable econ "dummy variable, 1 if economist"
label variable econ "economist"
 
generate native=0
replace native=1 if mother_tongue=="german"
*label variable native "dummy variable, 1 if native speaker"
label variable native "native speaker"
 
tabulate native if round==1

generate climate=0
replace climate=1 if climate_change=="Sehr gross"
label variable climate "climate concern"

tabulate climate if round==1

generate climate_recht=0
replace climate_recht=1 if climate_change=="Recht gross"
label variable climate_recht "climate concern recht gross"

tabulate climate_recht if round==1

generate climate_rs=0
replace climate_rs=1 if (climate_change=="Recht gross" | climate_change=="Sehr gross")
label variable climate_rs "climate concern recht oder sehr gross"

tabulate climate_rs if round==1

generate Gruen=0
replace Gruen=1 if political_affiliation=="Gruene"

generate CDU=0
replace CDU=1 if political_affiliation=="CDU/CSU"

generate SPD=0
replace SPD=1 if political_affiliation=="SPD"

generate FDP=0
replace FDP=1 if political_affiliation=="FDP"

generate Linke=0
replace Linke=1 if political_affiliation=="Die Linke"

generate AFD=0
replace AFD=1 if political_affiliation=="AfD"

generate Sonst=0
replace Sonst=1 if political_affiliation=="Sonstige"

tabulate political_affiliation if round==1


generate RK=0
replace RK=1 if relegion=="Roemisch-katholische Kirche"

generate EK=0
replace EK=1 if relegion=="Evangelische Kirche"

generate NR=0
replace NR=1 if relegion=="Keiner"

generate NC=0
replace NC=1 if relegion=="Nicht-christliche Religionsgemeinschaft"

generate AC=0
replace AC=1 if relegion=="Andere christliche Religionsgemeinschaft"

tabulate relegion if round==1




***** Generating a commitment variable 

generate commit=0
replace commit=min_a if type == 1
replace commit=min_b if type == 2
replace commit=min_c if type == 3
replace commit=min_d if type == 4

tabulate commit


***** Expressing results in percent of the efficient investment (=75)

gen commit_pc = commit*100/75
gen investment_pc = investment*100/75



*generate kyoto_NE=0
*replace kyoto_NE=1 if kyoto==1 & notenforced==1

*generate kyoto_S=0
*replace kyoto_S=1 if kyoto==1 & symmetric==1

*generate min_NE=0
*replace min_NE=1 if min==1 & notenforced==1

*generate min_S=0
*replace min_S=1 if min==1 & symmetric==1





save CLIMATE.dta, replace






************************************************************************
***************                                         ****************
***************     DESCRIPTIVE STATISTICS              ****************
***************                                         ****************
************************************************************************

clear
capture log close
set matsize 800
set more off
use CLIMATE.dta


*****+*********************************************************
*** 			Data for Extended Data Table 2              ***
***************************************************************


*** How many observations do we have in each treatment:

tab sub_treatment

tab sub_treatment matching if round==1



*** How many females do we have in each treatment


tab sub_treatment female if round==1, row



*** Age distribution across treatments

tab sub_treatment ageclass if round==1, row

tabulate sub_treatment, summarize(age)


***  Mother tongue

tab sub_treatment mother_tongue if round==1, row


*** Fields of study across treatments

tab sub_treatment field if round==1, row


*** Average payment to subjects:

summarize money







***********************************************************************
***********************************************************************
****                                                               ****
****          Results reported in Paper                     ****
****                                                               ****
***********************************************************************
***********************************************************************


*** Figure 1: Main Treatments (asymmetric enforced)

*** participation rates across treatments
*** Commitments and investments across treatments
*** computed with respect to all subjects, regardless of whether 
*** they participated in negotiations or not
*** Computation of standard errors clustered at matching group level

summarize participate if IC_M==1
sem participate if IC_M==1, vce(cluster match) 

summarize participate if CCC_M==1
sem participate if CCC_M==1, vce(cluster match) 

summarize participate if UCC_M==1
sem participate if UCC_M==1, vce(cluster match) 


summarize commit_pc if IC_M==1
sem commit_pc if IC_M==1, vce(cluster match) 

summarize commit_pc if CCC_M==1
sem commit_pc if CCC_M==1, vce(cluster match) 

summarize commit_pc if UCC_M==1
sem commit_pc if UCC_M==1, vce(cluster match) 


summarize investment_pc if IC_M==1
sem investment_pc if IC_M==1, vce(cluster match) 

summarize investment_pc if CCC_M==1
sem investment_pc if CCC_M==1, vce(cluster match) 

summarize investment_pc if UCC_M==1
sem investment_pc if UCC_M==1, vce(cluster match) 

summarize agreement if CCC_M==1 
sem agreement if CCC_M==1, vce(cluster match) 


*** Aside
*** Clustering on subject level yields smaller standard errors:
by sub_treatment, sort: sem participate, vce(cluster subject_code)
by sub_treatment, sort: sem commit_pc, vce(cluster subject_code)
by sub_treatment, sort: sem investment_pc, vce(cluster subject_code)
by sub_treatment, sort: sem agreement, vce(cluster subject_code)
*** We used standard errors clustered at the matching group level!



*** Auf einer Skala von 1 („Stimme gar nicht zu“) bis 7 („Stimme voll und ganz zu“: 
*** Wenn die Verhandlung zu keinen oder nur geringen Investitionsverpflichtungen geführt hat, lag das daran, 
*** dass zu wenig Zeit für die Verhandlung vorgesehen war.

summarize time_for_negotiations
by sub_treatment, sort: tabstat time_for_negotiations, statistics(mean sd sem n)
tabulate time_for_negotiations if IC_M==1
tabulate time_for_negotiations if UCC_M==1
tabulate time_for_negotiations if CCC_M==1






*** Figure 2:

summarize commit_pc if IC_M==1 & participate==1 & coalition==2
summarize commit_pc if IC_M==1 & participate==1 & coalition==3
summarize commit_pc if IC_M==1 & participate==1 & coalition==4

summarize commit_pc if CCC_M==1 & participate==1 & coalition==2
summarize commit_pc if CCC_M==1 & participate==1 & coalition==3
summarize commit_pc if CCC_M==1 & participate==1 & coalition==4

summarize commit_pc if UCC_M==1 & participate==1 & coalition==2
summarize commit_pc if UCC_M==1 & participate==1 & coalition==3
summarize commit_pc if UCC_M==1 & participate==1 & coalition==4


sem commit_pc if IC_M==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if IC_M==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if IC_M==1 & participate==1 & coalition==4, vce(cluster match) 

sem commit_pc if CCC_M==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if CCC_M==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if CCC_M==1 & participate==1 & coalition==4, vce(cluster match) 

sem commit_pc if UCC_M==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if UCC_M==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if UCC_M==1 & participate==1 & coalition==4, vce(cluster match) 


tabulate coalition if IC_M==1 & participate==1
tabulate coalition if CCC_M==1 & participate==1
tabulate coalition if UCC_M==1 & participate==1

tabulate agreement if CCC_M==1 & participate==1 & coalition==2
tabulate agreement if CCC_M==1 & participate==1 & coalition==3
tabulate agreement if CCC_M==1 & participate==1 & coalition==4



*** Figure 3 (No enforcement Treatments):

*** participation rates across treatments
*** Commitments and investments across treatments
*** computed with respect to all subjects, regardless of whether 
*** they participated in negotiations or not
*** Computation of standard errors clustered at matching group level

summarize participate if IC_NE==1
sem participate if IC_NE==1, vce(cluster match) 

summarize participate if CCC_NE==1
sem participate if CCC_NE==1, vce(cluster match) 

summarize participate if UCC_NE==1
sem participate if UCC_NE==1, vce(cluster match) 


summarize commit_pc if IC_NE==1
sem commit_pc if IC_NE==1, vce(cluster match) 

summarize commit_pc if CCC_NE==1
sem commit_pc if CCC_NE==1, vce(cluster match) 

summarize commit_pc if UCC_NE==1
sem commit_pc if UCC_NE==1, vce(cluster match) 


summarize investment_pc if IC_NE==1
sem investment_pc if IC_NE==1, vce(cluster match) 

summarize investment_pc if CCC_NE==1
sem investment_pc if CCC_NE==1, vce(cluster match) 

summarize investment_pc if UCC_NE==1
sem investment_pc if UCC_NE==1, vce(cluster match)


summarize agreement if CCC_NE==1 
sem agreement if CCC_NE==1, vce(cluster match) 



*** Figure S1: 

summarize commit_pc if IC_NE==1 & participate==1 & coalition==2
summarize commit_pc if IC_NE==1 & participate==1 & coalition==3
summarize commit_pc if IC_NE==1 & participate==1 & coalition==4

summarize commit_pc if CCC_NE==1 & participate==1 & coalition==2
summarize commit_pc if CCC_NE==1 & participate==1 & coalition==3
summarize commit_pc if CCC_NE==1 & participate==1 & coalition==4

summarize commit_pc if UCC_NE==1 & participate==1 & coalition==2
summarize commit_pc if UCC_NE==1 & participate==1 & coalition==3
summarize commit_pc if UCC_NE==1 & participate==1 & coalition==4


sem commit_pc if IC_NE==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if IC_NE==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if IC_NE==1 & participate==1 & coalition==4, vce(cluster match) 

sem commit_pc if CCC_NE==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if CCC_NE==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if CCC_NE==1 & participate==1 & coalition==4, vce(cluster match) 

sem commit_pc if UCC_NE==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if UCC_NE==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if UCC_NE==1 & participate==1 & coalition==4, vce(cluster match) 


tabulate coalition if IC_NE==1 & participate==1
tabulate coalition if CCC_NE==1 & participate==1
tabulate coalition if UCC_NE==1 & participate==1

tabulate agreement if CCC_NE==1 & participate==1 & coalition==2
tabulate agreement if CCC_NE==1 & participate==1 & coalition==3
tabulate agreement if CCC_NE==1 & participate==1 & coalition==4


*** Figure S2: Symmetry Treatments 

*** participation rates across treatments
*** Commitments and investments across treatments
*** computed with respect to all subjects, regardless of whether 
*** they participated in negotiations or not
*** Computation of standard errors clustered at matching group level

summarize participate if IC_S==1
sem participate if IC_S==1, vce(cluster match) 

summarize participate if CCC_S==1
sem participate if CCC_S==1, vce(cluster match) 

summarize participate if UCC_S==1
sem participate if UCC_S==1, vce(cluster match) 


summarize commit_pc if IC_S==1
sem commit_pc if IC_S==1, vce(cluster match) 

summarize commit_pc if CCC_S==1
sem commit_pc if CCC_S==1, vce(cluster match) 

summarize commit_pc if UCC_S==1
sem commit_pc if UCC_S==1, vce(cluster match) 


summarize investment_pc if IC_S==1
sem investment_pc if IC_S==1, vce(cluster match) 

summarize investment_pc if CCC_S==1
sem investment_pc if CCC_S==1, vce(cluster match) 

summarize investment_pc if UCC_S==1
sem investment_pc if UCC_S==1, vce(cluster match) 

summarize agreement if CCC_S==1 
sem agreement if CCC_S==1, vce(cluster match) 



*** Figure S3: Symmetry Treatments

summarize commit_pc if IC_S==1 & participate==1 & coalition==2
summarize commit_pc if IC_S==1 & participate==1 & coalition==3
summarize commit_pc if IC_S==1 & participate==1 & coalition==4

summarize commit_pc if CCC_S==1 & participate==1 & coalition==2
summarize commit_pc if CCC_S==1 & participate==1 & coalition==3
summarize commit_pc if CCC_S==1 & participate==1 & coalition==4

summarize commit_pc if UCC_S==1 & participate==1 & coalition==2
summarize commit_pc if UCC_S==1 & participate==1 & coalition==3
summarize commit_pc if UCC_S==1 & participate==1 & coalition==4


sem commit_pc if IC_S==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if IC_S==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if IC_S==1 & participate==1 & coalition==4, vce(cluster match) 

sem commit_pc if CCC_S==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if CCC_S==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if CCC_S==1 & participate==1 & coalition==4, vce(cluster match) 

sem commit_pc if UCC_S==1 & participate==1 & coalition==2, vce(cluster match) 
sem commit_pc if UCC_S==1 & participate==1 & coalition==3, vce(cluster match) 
sem commit_pc if UCC_S==1 & participate==1 & coalition==4, vce(cluster match) 


tabulate coalition if IC_S==1 & participate==1
tabulate coalition if CCC_S==1 & participate==1
tabulate coalition if UCC_S==1 & participate==1

tabulate agreement if CCC_S==1 & participate==1 & coalition==2
tabulate agreement if CCC_S==1 & participate==1 & coalition==3
tabulate agreement if CCC_S==1 & participate==1 & coalition==4



 








***************************************************************
*** 			Non-parametric Tests                        ***
***************************************************************

*** Participation

*** Fisher's exact test
tab participate sub_treatment if (CCC_M==1 | UCC_M==1 | IC_M==1), col exact
tab participate sub_treatment if (CCC_M==1 | UCC_M==1), col exact
tab participate sub_treatment if (CCC_M==1 | IC_M==1), col exact
tab participate sub_treatment if (IC_M==1 | UCC_M==1), col exact

*** Chi^2 Test on difference between the three main treatments with enforcement
*tab participate sub_treatment if (K==1 | M==1 | P==1), col chi2
*tab participate sub_treatment if (K==1 | M==1), col chi2
*tab participate sub_treatment, col chi2

*** Commitment and Investments

*** Wilconson rank-sum test (also known as Mann-Whitney U test)
ranksum commit if (UCC_M==1 | CCC_M==1), by(UCC_M)
ranksum commit if (UCC_M==1 | IC_M==1), by(UCC_M)
ranksum commit if (IC_M==1 | CCC_M==1), by(CCC_M)

ranksum investment if (UCC_M==1 | CCC_M==1), by(UCC_M)
ranksum investment if (UCC_M==1 | IC_M==1), by(UCC_M)
ranksum investment if (IC_M==1 | CCC_M==1), by(CCC_M)



*** No Enforcement Treatments:

*** Participation
*** Fisher's exact test
tab participate sub_treatment if (CCC_NE==1 | UCC_NE==1 | IC_NE==1), col exact
*tab participate sub_treatment if (KNE==1 | MNE==1), col exact
*tab participate sub_treatment if (KNE==1 | PNE==1), col exact
*tab participate sub_treatment if (PNE==1 | MNE==1), col exact


*** Commitment and Investment
*** Wilconson rank-sum test (also known as Mann-Whitney U test)
ranksum commit if (UCC_NE==1 | CCC_NE==1), by(UCC_NE)
ranksum commit if (UCC_NE==1 | IC_NE==1), by(UCC_NE)
ranksum commit if (IC_NE==1 | CCC_NE==1), by(CCC_NE)

ranksum investment if (UCC_NE==1 | CCC_NE==1), by(UCC_NE)
ranksum investment if (UCC_NE==1 | IC_NE==1), by(UCC_NE)
ranksum investment if (IC_NE==1 | CCC_NE==1), by(CCC_NE)


*** Correlation between investments and commitments

correlate commit investment if (CCC_NE==1 | UCC_NE==1 | IC_NE==1)

reg investment commit if (CCC_NE==1 | UCC_NE==1 | IC_NE==1)


*** Comparison of the investment levels in UCC with enforcement 
*** and IC and CCC without enforcement
*** Wilconson rank-sum test (also known as Mann-Whitney U test)
*** median test

ranksum investment if (CCC_NE==1 | UCC_M==1), by(UCC_M)
ranksum investment if (IC_NE==1 | UCC_M==1), by(UCC_M)

median investment if (CCC_NE==1 | UCC_M==1), by(UCC_M) exact
median investment if (IC_NE==1 | UCC_M==1), by(UCC_M) exact


*** Symmetry Treatments:

*** Participation
*** Fisher's exact test
tab participate sub_treatment if (CCC_S==1 | UCC_S==1 | IC_S==1), col exact
*tab participate sub_treatment if (KS==1 | MS==1), col exact
*tab participate sub_treatment if (KS==1 | PS==1), col exact
*tab participate sub_treatment if (PS==1 | MS==1), col exact

*** Commitment and Investment
*** Wilconson rank-sum test (also known as Mann-Whitney U test)
ranksum commit if (UCC_S==1 | CCC_S==1), by(UCC_S)
ranksum commit if (UCC_S==1 | IC_S==1), by(UCC_S)
ranksum commit if (IC_S==1 | CCC_S==1), by(CCC_S)

ranksum investment if (UCC_S==1 | CCC_S==1), by(UCC_S)
ranksum investment if (UCC_S==1 | IC_S==1), by(UCC_S)
ranksum investment if (IC_S==1 | CCC_S==1), by(CCC_S)



*****************************************************************************
*****                                                         ***************
*****      ADDITIONAL REGRESSIONS							  ***************
*****                                                         ***************
*****************************************************************************

	
	
*****************************************************************************
****   Table S3: Main Treatment (clustered at matching group level)     *****
*****************************************************************************


* COLUMN 1: PARTICIPATE
reg participate CCC UCC round B C D if main==1, cluster(match) 
outreg2 using Table_3.xls, replace ctitle(Participate) title(Extended Data Table 3. Main Enforcement Treatments (clustered at matching group level)) /*
    */ sortvar(CCC UCC round B C D)/*
	*/ addtext ("Sample", "IC; CCC; UCC")


	

* COLUMN 1: COMMITMENT
reg commit CCC UCC round B C D if (main==1), cluster(match) 
outreg2 using Table_3.xls, append ctitle(Commit) label /*
    */ sortvar(CCC UCC round B C D)/*
	*/ addtext ("Sample", "IC; CCC; UCC")





	
* COLUMN 3: INVESTMENT
reg investment CCC UCC round B C D if main==1, cluster(match) 
outreg2 using Table_3.xls, append ctitle(Invest) label /*
    */ sortvar(CCC UCC round B C D)/*
	*/ addtext ("Sample", "IC; CCC; UCC")

	



* COLUMN 4: PAYOFFS
reg payoff CCC UCC round B C D if main==1, cluster(match) 
outreg2 using Table_3.xls, append ctitle(Payoff) label /*
    */ sortvar(CCC UCC round B C D)/*
	*/ addtext ("Sample", "IC; CCC; UCC")


	
*** Regressions with additional controls:

reg participate CCC UCC round B C D if main==1, cluster(match)
reg participate CCC UCC round B C D female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC if main==1, cluster(match) 

reg commit CCC UCC round B C D if (main==1), cluster(match)
reg commit CCC UCC round B C D female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC if (main==1), cluster(match)

reg investment CCC UCC round B C D if main==1, cluster(match) 
reg investment CCC UCC round B C D female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC if main==1, cluster(match)

reg payoff CCC UCC round B C D if main==1, cluster(match) 
reg payoff CCC UCC round B C D female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC if main==1, cluster(match) 


*****************************************************************************
****   Table S4: All Treatments (clustered at matching group level)     *****
*****************************************************************************


	
* COLUMN 1: PARTICIPATE
reg participate CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match)
outreg2 using Table_4.xls, replace ctitle(Participate)  title(Extended Data Table 4. All Treatments (clustered at matching group level)) /*
    */ sortvar(CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA)/*
	*/ addtext ("Sample", "all")



	
			
* COLUMN 2: COMMITMENT
reg commit CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match) 
outreg2 using Table_4.xls, append ctitle(Commit) label /*
    */ sortvar(CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA)/*
	*/ addtext ("Sample", "all")
	
	


* COLUMN 3: INVESTMENT
reg investment CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match) 
outreg2 using Table_4.xls, append ctitle(Invest) label /*
    */ sortvar(CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA)/*
	*/ addtext ("Sample", "all")

	


* COLUMN 4: PAYOFFS
reg payoff CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match)
outreg2 using Table_4.xls, append ctitle(Payoff) label /*
    */ sortvar(CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA)/*
	*/ addtext ("Sample", "all")
	
	


*** Regressions with additional controls:
reg participate CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match)
reg participate CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC, cluster(match)


reg commit CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match)
reg commit CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC, cluster(match)


reg investment CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match)
reg investment CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC, cluster(match)


reg payoff CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA, cluster(match)
reg payoff CCC UCC notenforced symmetric CCC_NE CCC_S UCC_NE UCC_S round BA CA DA female ageclass econ native climate_rs Gruen CDU SPD FDP Linke AFD RK EK NC AC, cluster(match)

